from numpy import linspace, exp, inf
from pylab import figure, plot, savefig, show

# Plank's law for blackbody radiation
c1 = 3.7413*10**8 # W \mu m^4/m^2
c2 = 1.4388*10**4 # \mu m K
T = 1000.0 # T = temperature in K


# monochromatic emissive power of a blackbody:
def Eblam(lam, T=1000.0):
    # lam = wavelength in \um
    return c1 / (lam**5 * (exp(c2/(lam*T)) -1.0))


print('------------ plot ---------------')
y = linspace(0.01, 10, 1000)
figure()
plot(y, Eblam(y,1600.0) / 10.0**4)
savefig("E.png")
show()


print('------------ integrate: quad ---------------')
from scipy import integrate

# total energy lost per unit area
Q, abserr, info = integrate.quad(Eblam,0,inf, full_output=True)
neval = info['neval']
# Q = sigma * T^4; sigma = Stefan-Boltzmann constant
print(Q/T**4, abserr, 'neval=', neval)

T = 200.#5778.
Q, abserr, info = integrate.quad(Eblam,0,inf, args=(T), full_output=True)
neval = info['neval']
# Q = sigma * T^4; sigma = Stefan-Boltzmann constant
print(Q/T**4, abserr, 'neval=', neval)


print('------------ integrate: simpson ---------------')
from simpson import simpson
for N in range(20,50):
    print(simpson(Eblam,0.01,20.,N)/1000**4, N)


print('------------ integrate: simpsadapt ---------------')
from simpsadapt import simpsadapt
a = simpsadapt(Eblam,0.01,200.,eps=1E-6)
print(a, a[0]/1000**4)
