from numpy import linspace, sum, inf
def simpsadapt(func,a,b,Nmax=10**8,eps=1E-6):
        """
        Numerical quadrature based on Simpson rule
        func: handle to y = f(x)
        a,b: bounds of integration interval
        N+1: number of equidistant quadrature points
        """
        
        # ensure that we have an even number of subintervals
        if Nmax%2 == 1: Nmax = Nmax+1
        # quadrature nodes
        N = 2
        x = linspace(a,b,N+1); h = x[1]-x[0]
        I0 = h*sum(func(x[0:-2:2]) + 4*func(x[1:-1:2]) + func(x[2::2]))/3.0
        N *=2
        err = inf
        while N<=Nmax:        
            x = linspace(a,b,N+1); h = x[1]-x[0]
            I1 = h*sum(func(x[0:-2:2]) + 4*func(x[1:-1:2]) + func(x[2::2]))/3.0
            err = abs(I0-I1)
            if err < eps:
                break
            I0 = I1
            N *= 2
        return I0, err, N
